@@ -37,11 +37,12 @@ DEFAULT_CLUSTER_RETRY_EXCEPTIONS = {
     InternalServerError: [
         "etcdserver: leader changed",
         "etcdserver: request timed out",
+        "Internal error occurred: failed calling webhook",
     ],
     ServerTimeoutError: [],
 }
 
-LOGGER = get_logger(name=__name__)
+LOGGER = get_logger(__name__)
 MAX_SUPPORTED_API_VERSION = "v2"
 
 
@@ -414,6 +415,7 @@ class Resource:
         self.node_selector_spec = self._prepare_node_selector_spec()
         self.res = None
         self.yaml_file_contents = None
+        self.logger = get_logger(name=f"{__name__.rsplit('.')[0]} {self.kind}")
 
     def _prepare_node_selector_spec(self):
         if self.node_selector:
@@ -539,7 +541,7 @@ class Resource:
             user_exported_args=skip_resource_teardown,
             check_exists=False,
         ):
-            LOGGER.warning(
+            self.logger.warning(
                 f"Skip resource {self.kind} {self.name} teardown. Got {_export_str}={skip_resource_teardown}"
             )
             return
@@ -618,7 +620,7 @@ class Resource:
         Raises:
             TimeoutExpiredError: If resource not exists.
         """
-        LOGGER.info(f"Wait until {self.kind} {self.name} is created")
+        self.logger.info(f"Wait until {self.kind} {self.name} is created")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=sleep,
@@ -642,7 +644,7 @@ class Resource:
         Raises:
             TimeoutExpiredError: If resource still exists.
         """
-        LOGGER.info(f"Wait until {self.kind} {self.name} is deleted")
+        self.logger.info(f"Wait until {self.kind} {self.name} is deleted")
         return self.client_wait_deleted(timeout=timeout)
 
     @property
@@ -687,7 +689,7 @@ class Resource:
             TimeoutExpiredError: If resource in not in desire status.
         """
         stop_status = stop_status if stop_status else self.Status.FAILED
-        LOGGER.info(f"Wait for {self.kind} {self.name} status to be {status}")
+        self.logger.info(f"Wait for {self.kind} {self.name} status to be {status}")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=sleep,
@@ -713,15 +715,16 @@ class Resource:
 
         except TimeoutExpiredError:
             if current_status:
-                LOGGER.error(f"Status of {self.kind} {self.name} is {current_status}")
+                self.logger.error(
+                    f"Status of {self.kind} {self.name} is {current_status}"
+                )
             raise
 
-    def create(self, body=None, wait=False):
+    def create(self, wait=False):
         """
         Create resource.
 
         Args:
-            body (dict): Resource data to create.
             wait (bool) : True to wait for resource status.
 
         Returns:
@@ -731,33 +734,20 @@ class Resource:
             ValueMismatch: When body value doesn't match class value
         """
         data = self.to_dict()
-        if body:
-            kind = body["kind"]
-            name = body.get("name")
-            api_version = body["apiVersion"]
-            if kind != self.kind:
-                raise ValueMismatch(f"{kind} != {self.kind}")
-            if name and name != self.name:
-                raise ValueMismatch(f"{name} != {self.name}")
-            if api_version != self.api_version:
-                raise ValueMismatch(f"{api_version} != {self.api_version}")
-
-            data.update(body)
-
-        LOGGER.info(f"Create {self.kind} {self.name}")
-        LOGGER.info(f"Posting {data}")
-        LOGGER.debug(f"\n{yaml.dump(data)}")
+        self.logger.info(f"Create {self.kind} {self.name}")
+        self.logger.info(f"Posting {data}")
+        self.logger.debug(f"\n{yaml.dump(data)}")
         res = self.api.create(body=data, namespace=self.namespace, dry_run=self.dry_run)
         if wait and res:
             return self.wait()
         return res
 
     def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
-        LOGGER.info(f"Delete {self.kind} {self.name}")
+        self.logger.info(f"Delete {self.kind} {self.name}")
         if self.exists:
             data = self.instance.to_dict()
-            LOGGER.info(f"Deleting {data}")
-            LOGGER.debug(f"\n{yaml.dump(data)}")
+            self.logger.info(f"Deleting {data}")
+            self.logger.debug(f"\n{yaml.dump(data)}")
 
         try:
             res = self.api.delete(name=self.name, namespace=self.namespace, body=body)
@@ -778,7 +768,7 @@ class Resource:
         Returns:
            str: Status
         """
-        LOGGER.info(f"Get {self.kind} {self.name} status")
+        self.logger.info(f"Get {self.kind} {self.name} status")
         return self.instance.status.phase
 
     def update(self, resource_dict):
@@ -788,8 +778,8 @@ class Resource:
         Args:
             resource_dict: Resource dictionary
         """
-        LOGGER.info(f"Update {self.kind} {self.name}:\n{resource_dict}")
-        LOGGER.debug(f"\n{yaml.dump(resource_dict)}")
+        self.logger.info(f"Update {self.kind} {self.name}:\n{resource_dict}")
+        self.logger.debug(f"\n{yaml.dump(resource_dict)}")
         self.api.patch(
             body=resource_dict,
             namespace=self.namespace,
@@ -801,8 +791,8 @@ class Resource:
         Replace resource metadata.
         Use this to remove existing field. (update() will only update existing fields)
         """
-        LOGGER.info(f"Replace {self.kind} {self.name}: \n{resource_dict}")
-        LOGGER.debug(f"\n{yaml.dump(resource_dict)}")
+        self.logger.info(f"Replace {self.kind} {self.name}: \n{resource_dict}")
+        self.logger.debug(f"\n{yaml.dump(resource_dict)}")
         self.api.replace(body=resource_dict, name=self.name, namespace=self.namespace)
 
     @staticmethod
@@ -894,7 +884,7 @@ class Resource:
         Raises:
             TimeoutExpiredError: If Pod condition in not in desire status.
         """
-        LOGGER.info(
+        self.logger.info(
             f"Wait for {self.kind}/{self.name}'s '{condition}' condition to be '{status}'"
         )
         samples = TimeoutSampler(
