@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
 
 
@@ -19,6 +19,8 @@ class Route(NamespacedResource):
         destination_ca_cert=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -26,6 +28,8 @@ class Route(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.service = service
         self.destination_ca_cert = destination_ca_cert
